@@ -1,5 +1,7 @@
-/*  This file is part of LingoTeach, the Language Teaching program 
- *  Copyright (C) 2001-2003 The LingoTeach Team
+/*  $Id: tmeaning.c,v 1.3 2004/09/10 10:43:29 marcusva Exp $
+ * 
+ *  This file is part of LingoTeach, the Language Teaching program 
+ *  Copyright (C) 2001-2004 Marcus von Appen. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify 
  *  it under the terms of the GNU General Public License as published by 
@@ -19,7 +21,7 @@
 #include "lingoteach.h"
 
 int 
-main (int argc, char *argv[])
+main (void)
 {
   return 0;
 }
